==> libbpp-seq_2.0.2.orig.tar.gz: bpp-seq-2.0.2/test/test_alphabets.cpp <==
//
// File: test_alphabets.cpp
// Created by: Julien Dutheil
// Created on: Sat Oct 30 17:10 2010
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for numerical calculus. This file is part of the Bio++ project.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include <Bpp/Seq/Alphabet.all>
#include <iostream>

using namespace bpp;
using namespace std;

int main() {
  //This is a very simple test that instanciate all alpahabet classes.
  NucleicAlphabet* dna = new DNA;
  NucleicAlphabet* rna = new RNA;
  Alphabet* pro = new ProteicAlphabet;
  Alphabet* def = new DefaultAlphabet;
  Alphabet* stdCdn = new StandardCodonAlphabet(rna);
  Alphabet* vmtCdn = new VertebrateMitochondrialCodonAlphabet(rna);
  Alphabet* imtCdn = new InvertebrateMitochondrialCodonAlphabet(rna);
  Alphabet* emtCdn = new EchinodermMitochondrialCodonAlphabet(rna);
  Alphabet* ymtCdn = new YeastMitochondrialCodonAlphabet(rna);

  delete dna;
  delete rna;
  delete pro;
  delete def;
  delete stdCdn;
  delete vmtCdn;
  delete imtCdn;
  delete emtCdn;
  delete ymtCdn;

  return (0);
}

==> libbpp-seq_2.0.3.orig.tar.gz: bpp-seq-2.0.3/test/test_alphabets.cpp <==
//
// File: test_alphabets.cpp
// Created by: Julien Dutheil
// Created on: Sat Oct 30 17:10 2010
//

/*
Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)

This software is a computer program whose purpose is to provide classes
for numerical calculus. This file is part of the Bio++ project.

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.
*/

#include <Bpp/Seq/Alphabet.all>
#include <iostream>

using namespace bpp;
using namespace std;

int main() {
  //This is a very simple test that instanciate all alpahabet classes.
  NucleicAlphabet* dna = new DNA();
  NucleicAlphabet* rna = new RNA();
  Alphabet* pro = new ProteicAlphabet;
  Alphabet* def = new DefaultAlphabet;
  Alphabet* stdCdn = new StandardCodonAlphabet(rna);
  Alphabet* vmtCdn = new VertebrateMitochondrialCodonAlphabet(rna);
  Alphabet* imtCdn = new InvertebrateMitochondrialCodonAlphabet(rna);
  Alphabet* emtCdn = new EchinodermMitochondrialCodonAlphabet(rna);
  Alphabet* ymtCdn = new YeastMitochondrialCodonAlphabet(rna);

  delete dna;
  delete rna;
  delete pro;
  delete def;
  delete stdCdn;
  delete vmtCdn;
  delete imtCdn;
  delete emtCdn;
  delete ymtCdn;

  return (0);
}
